=== modified file 'drizzled/db.cc'
--- drizzled/db.cc	2009-04-10 18:16:15 +0000
+++ drizzled/db.cc	2009-05-14 08:35:31 +0000
@@ -148,19 +148,16 @@
     set, even if the database does not exist.
 */
 
-const CHARSET_INFO *get_default_db_collation(Session *session, const char *db_name)
+const CHARSET_INFO *get_default_db_collation(const char *db_name)
 {
   HA_CREATE_INFO db_info;
 
-  if (session->db != NULL && strcmp(db_name, session->db) == 0)
-    return session->db_charset;
-
   /*
     db_info.default_table_charset contains valid character set
     (collation_server).
   */
 
-  load_db_opt_by_name(session, db_name, &db_info);
+  load_db_opt_by_name(db_name, &db_info);
 
   return db_info.default_table_charset;
 }
@@ -211,13 +208,12 @@
   return 0;
 }
 
-int load_db_opt(Session *session, const char *path, HA_CREATE_INFO *create)
+int load_db_opt(const char *path, HA_CREATE_INFO *create)
 {
   drizzled::message::Schema db;
-  string buffer;
 
   memset(create, 0, sizeof(*create));
-  create->default_table_charset= session->variables.collation_server;
+  create->default_table_charset= default_charset_info;
 
   int fd= open(path, O_RDONLY);
 
@@ -231,21 +227,25 @@
   }
   close(fd);
 
-  buffer= db.collation();
-  if (!(create->default_table_charset= get_charset_by_name(buffer.c_str())))
+  /* If for some reason the db.opt file lacks a collation, we just return the default */
+  if (db.has_collation())
   {
-    errmsg_printf(ERRMSG_LVL_ERROR,
-		  _("Error while loading database options: '%s':"),path);
-    errmsg_printf(ERRMSG_LVL_ERROR, ER(ER_UNKNOWN_COLLATION), buffer.c_str());
-    create->default_table_charset= default_charset_info;
-    return -1;
+    string buffer;
+    buffer= db.collation();
+    if (!(create->default_table_charset= get_charset_by_name(buffer.c_str())))
+    {
+      errmsg_printf(ERRMSG_LVL_ERROR,
+                    _("Error while loading database options: '%s':"),path);
+      errmsg_printf(ERRMSG_LVL_ERROR, ER(ER_UNKNOWN_COLLATION), buffer.c_str());
+      create->default_table_charset= default_charset_info;
+      return -1;
+    }
   }
 
   return 0;
 }
 
-int load_db_opt_by_name(Session *session, const char *db_name,
-			HA_CREATE_INFO *db_create_info)
+int load_db_opt_by_name(const char *db_name, HA_CREATE_INFO *db_create_info)
 {
   char db_opt_path[FN_REFLEN];
 
@@ -256,7 +256,7 @@
   (void) build_table_filename(db_opt_path, sizeof(db_opt_path),
                               db_name, "", MY_DB_OPT_FILE, 0);
 
-  return load_db_opt(session, db_opt_path, db_create_info);
+  return load_db_opt(db_opt_path, db_create_info);
 }
 
 
@@ -1061,7 +1061,7 @@
     attributes and will be freed in Session::~Session().
   */
 
-  db_default_cl= get_default_db_collation(session, new_db_file_name.str);
+  db_default_cl= get_default_db_collation(new_db_file_name.str);
 
   mysql_change_db_impl(session, &new_db_file_name, db_default_cl);
 

=== modified file 'drizzled/db.h'
--- drizzled/db.h	2009-02-02 04:55:56 +0000
+++ drizzled/db.h	2009-05-14 08:35:31 +0000
@@ -34,9 +34,8 @@
 
 
 bool check_db_dir_existence(const char *db_name);
-int load_db_opt_by_name(Session *session, const char *db_name,
-			HA_CREATE_INFO *db_create_info);
-const CHARSET_INFO *get_default_db_collation(Session *session, const char *db_name);
+int load_db_opt_by_name(const char *db_name, HA_CREATE_INFO *db_create_info);
+const CHARSET_INFO *get_default_db_collation(const char *db_name);
 
 extern int creating_database; // How many database locks are made
 extern int creating_table;    // How many mysql_create_table() are running

=== modified file 'drizzled/show.cc'
--- drizzled/show.cc	2009-05-09 22:57:25 +0000
+++ drizzled/show.cc	2009-05-14 08:35:31 +0000
@@ -412,7 +412,7 @@
   String buffer(buff, sizeof(buff), system_charset_info);
   Protocol *protocol=session->protocol;
 
-  if (store_db_create_info(session, dbname, &buffer, create_info))
+  if (store_db_create_info(dbname, &buffer, create_info))
   {
     /*
       This assumes that the only reason for which store_db_create_info()
@@ -926,8 +926,7 @@
   @returns true if errors are detected, false otherwise.
 */
 
-bool store_db_create_info(Session *session, const char *dbname, String *buffer,
-                          HA_CREATE_INFO *create_info)
+bool store_db_create_info(const char *dbname, String *buffer, HA_CREATE_INFO *create_info)
 {
   HA_CREATE_INFO create;
   uint32_t create_options = create_info ? create_info->options : 0;
@@ -943,7 +942,7 @@
     if (check_db_dir_existence(dbname))
       return(true);
 
-    load_db_opt_by_name(session, dbname, &create);
+    load_db_opt_by_name(dbname, &create);
   }
 
   buffer->length(0);
@@ -2678,7 +2677,7 @@
     }
     {
       HA_CREATE_INFO create;
-      load_db_opt_by_name(session, db_name->str, &create);
+      load_db_opt_by_name(db_name->str, &create);
 
       if (store_schema_shemata(session, table, db_name,
                                create.default_table_charset))

=== modified file 'drizzled/show.h'
--- drizzled/show.h	2009-04-12 09:10:36 +0000
+++ drizzled/show.h	2009-05-14 08:35:31 +0000
@@ -55,8 +55,7 @@
 
 int store_create_info(Session *session, TableList *table_list, String *packet,
                       HA_CREATE_INFO  *create_info_arg);
-bool store_db_create_info(Session *session, const char *dbname, String *buffer,
-                          HA_CREATE_INFO *create_info);
+bool store_db_create_info(const char *dbname, String *buffer, HA_CREATE_INFO *create_info);
 bool schema_table_store_record(Session *session, Table *table);
 
 int get_quote_char_for_identifier(Session *session, const char *name,

=== modified file 'drizzled/sql_load.cc'
--- drizzled/sql_load.cc	2009-05-09 22:57:25 +0000
+++ drizzled/sql_load.cc	2009-05-14 08:35:31 +0000
@@ -294,8 +294,8 @@
   info.handle_duplicates=handle_duplicates;
   info.escape_char=escaped->length() ? (*escaped)[0] : INT_MAX;
 
-  READ_INFO read_info(file,tot_length,
-                      ex->cs ? ex->cs : session->variables.collation_database,
+  READ_INFO read_info(file, tot_length,
+                      ex->cs ? ex->cs : get_default_db_collation(session->db),
 		      *field_term,*ex->line_start, *ex->line_term, *enclosed,
 		      info.escape_char, is_fifo);
   if (read_info.error)

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2009-05-10 00:20:29 +0000
+++ drizzled/sql_table.cc	2009-05-14 08:35:31 +0000
@@ -79,22 +79,15 @@
                           HA_CREATE_INFO *create_info,
                           Alter_info *alter_info);
 
-static void set_table_default_charset(Session *session,
-                                      HA_CREATE_INFO *create_info, char *db)
+static void set_table_default_charset(HA_CREATE_INFO *create_info, char *db)
 {
   /*
     If the table character set was not given explicitly,
     let's fetch the database default character set and
     apply it to the table.
   */
-  if (!create_info->default_table_charset)
-  {
-    HA_CREATE_INFO db_info;
-
-    load_db_opt_by_name(session, db, &db_info);
-
-    create_info->default_table_charset= db_info.default_table_charset;
-  }
+  if (create_info->default_table_charset == NULL)
+    create_info->default_table_charset= get_default_db_collation(db);
 }
 
 /*
@@ -1708,7 +1701,7 @@
     return(true);
   }
 
-  set_table_default_charset(session, create_info, (char*) db);
+  set_table_default_charset(create_info, (char*) db);
 
   if (mysql_prepare_create_table(session, create_info, alter_info,
                                  internal_tmp_table,
@@ -4007,7 +4000,7 @@
   if (mysql_prepare_alter_table(session, table, create_info, alter_info))
       goto err;
 
-  set_table_default_charset(session, create_info, db);
+  set_table_default_charset(create_info, db);
 
   alter_info->build_method= HA_BUILD_OFFLINE;
 

=== modified file 'mysys/charset.cc'
--- mysys/charset.cc	2009-04-17 21:01:47 +0000
+++ mysys/charset.cc	2009-05-14 08:35:31 +0000
@@ -260,7 +260,7 @@
   const CHARSET_INFO *cs;
   (void) init_available_charsets(MYF(0));	/* If it isn't initialized */
 
-  cs_number=get_collation_number(cs_name);
+  cs_number= get_collation_number(cs_name);
   cs= cs_number ? get_internal_charset(cs_number) : NULL;
 
   return cs;

